/*------------------------------------------------------------------------------------
   Name: xSuperTrend_mq4
   Copyright 2011, Xaphod, http://wwww.xaphod.com
   
   Description: SuperTrend Indicator
	          
   Change log: 
       2014-05-28, Xaphod, v1.600
          - Update for MT4 build 600+
       2011-11-25. Xaphod, v1.00 
          - First Release 
-------------------------------------------------------------------------------------*/
// Indicator properties
#property copyright "2010, xaphod.com"
#property link      "http://wwww.xaphod.com"

#property strict
#property version    "1.600"
#property description "xSuperTrend Indicator"
#property description ""
#property description "SuperTrend Formula:"
#property description "  UpperLevel=(High[i]+Low[i])/2+Multiplier*Atr(Period);"
#property description "  LowerLevel=(High[i]+Low[i])/2-Multiplier*Atr(Period);"


#property indicator_chart_window
#property indicator_buffers 3
#property indicator_color1 Yellow
#property indicator_color2 FireBrick
#property indicator_color3 Green
#property indicator_width1 1
#property indicator_width2 2
#property indicator_width3 2
#property indicator_style1 STYLE_DOT
#property indicator_maximum 1
#property indicator_minimum 0

// Constant definitions
#define INDICATOR_NAME "xSuperTrend"

// Indicator parameters
extern double Factor=(4,1,10,0.1); // Factor 

extern int    Atr_Period=10;      // ATR Period


// Global module varables
double gdaUpBuf[];
double gdaDnBuf[];
double gdaSuperTrend[];


//-----------------------------------------------------------------------------
// function: init()
// Description: Custom indicator initialization function.
//-----------------------------------------------------------------------------
int init() {
   SetIndexStyle(0, DRAW_LINE);
   SetIndexBuffer(0, gdaSuperTrend);
   SetIndexLabel(0, "SuperTrend");
   SetIndexStyle(1, DRAW_LINE);
   SetIndexBuffer(1, gdaDnBuf);
   SetIndexLabel(1, "SuperTrend Down");
   SetIndexStyle(2, DRAW_LINE);
   SetIndexBuffer(2, gdaUpBuf);
   SetIndexLabel(2, "SuperTrend Up");
   IndicatorShortName(INDICATOR_NAME+"["+(string)Atr_Period+";"+DoubleToStr(Factor,1)+"]");
  return(0);
}


//-----------------------------------------------------------------------------
// function: deinit()
// Description: Custom indicator deinitialization function.
//-----------------------------------------------------------------------------
int deinit() {
   return (0);
}


///-----------------------------------------------------------------------------
// function: start()
// Description: Custom indicator iteration function.
//-----------------------------------------------------------------------------
int start() {
  int iNewBars, iCountedBars, i;
  double dAtr,dUpperLevel, dLowerLevel;  
  
  // Get unprocessed ticks
  iCountedBars=IndicatorCounted();
  if(iCountedBars < 0) return (-1); 
  if(iCountedBars>0) iCountedBars--;
  iNewBars=Bars-iCountedBars;
  
  for(i=iNewBars; i>=0; i--) {
    // Bounds check
    if (i>=Bars-1)
      continue;
      
    // Calc SuperTrend
    dAtr = iATR(NULL, 0, Atr_Period, i);
    dUpperLevel=(High[i]+Low[i])/2+Factor*dAtr;
    dLowerLevel=(High[i]+Low[i])/2-Factor*dAtr;
    
    // Set supertrend levels
    if (Close[i]>gdaSuperTrend[i+1] && Close[i+1]<=gdaSuperTrend[i+1]) {
      gdaSuperTrend[i]=dLowerLevel;
    }
    else if (Close[i]<gdaSuperTrend[i+1] && Close[i+1]>=gdaSuperTrend[i+1]) {
      gdaSuperTrend[i]=dUpperLevel;
    }
    else if (gdaSuperTrend[i+1]<dLowerLevel)
        gdaSuperTrend[i]=dLowerLevel;
    else if (gdaSuperTrend[i+1]>dUpperLevel)
        gdaSuperTrend[i]=dUpperLevel;
    else
      gdaSuperTrend[i]=gdaSuperTrend[i+1];
    
    // Draw SuperTrend lines
    gdaUpBuf[i]=EMPTY_VALUE;
    gdaDnBuf[i]=EMPTY_VALUE;
    if (Close[i]>gdaSuperTrend[i] || (Close[i]==gdaSuperTrend[i] && Close[i+1]>gdaSuperTrend[i+1])) 
      gdaUpBuf[i]=gdaSuperTrend[i];
    else if (Close[i]<gdaSuperTrend[i] || (Close[i]==gdaSuperTrend[i] && Close[i+1]<gdaSuperTrend[i+1])) 
      gdaDnBuf[i]=gdaSuperTrend[i];  
  }
  
  return(0);
}
//+------------------------------------------------------------------+



